.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

User Guide
----------

.. toctree::
   :maxdepth: 2

   user/install
   user/usage
   user/benchmark
   user/pso
   user/parallelization
   user/HowToCosmoHammer

API Documentation
-----------------

.. toctree::
   :maxdepth: 2

   api


Contents:
---------

.. toctree::
   :maxdepth: 2

   contributing
   authors
   history

  

License
-------
CosmoHammer is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CosmoHammer is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with CosmoHammer.  If not, see <http://www.gnu.org/licenses/>.
